@@ -25,6 +25,9 @@
 namespace Glom
 {
 
+const char* Box_Formatting::glade_id("box_formatting");
+const bool Box_Formatting::glade_developer(true);
+
 Box_Formatting::Box_Formatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::VBox(cobject),
   m_vbox_numeric_format(0),
